Struct Portsc1
Source #[repr(transparent)]
pub struct Portsc1(pub u32);
Port Enable/Disable Change
Port Enable/Disable Change
Wake on Connect Enable (WKCNNT_E)
Wake on Connect Enable (WKCNNT_E)
Wake on Disconnect Enable (WKDSCNNT_E)
Wake on Disconnect Enable (WKDSCNNT_E)
Wake on Over-current Enable (WKOC_E)
Wake on Over-current Enable (WKOC_E)
PHY Low Power Suspend - Clock Disable (PLPSCD)
PHY Low Power Suspend - Clock Disable (PLPSCD)
Port Force Full Speed Connect
Port Force Full Speed Connect
Parallel Transceiver Select
Parallel Transceiver Select
Parallel Transceiver Width - Read/Write
Parallel Transceiver Width - Read/Write
Serial Transceiver Select
Serial Transceiver Select
Parallel Transceiver Select
Parallel Transceiver Select
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.